@@ -1,8 +1,10 @@
 #!/bin/bash
 
-BIN_DIR=`dirname $0`
-LIB_DIR=$BIN_DIR/../lib
-LOGGING_PROPERTIES=$BIN_DIR/logging.properties
+BIN_DIR=$(cd $(dirname $0) && pwd)
+BASE_DIR=$(dirname $BIN_DIR)
+LIB_DIR=$BASE_DIR/lib
+TTF_DIR=$BASE_DIR/fonts
+LOG4J_CONF=$BIN_DIR/log4j.xml
 FONTS_PROPERTIES=$BIN_DIR/wdic-fonts.properties
 CHARS_PROPERTIES=$BIN_DIR/wdic-chars.properties
 
@@ -23,8 +25,9 @@ if [ -n "$JAVA_HOME" ]; then
   fi
 fi
 
-$JAVACMD -Xmx1024m -cp $CP \
-    -Djava.util.logging.config.file=$LOGGING_PROPERTIES \
+$JAVACMD -Xmx2048m -cp $CP \
+    -Dlog4j.configuration=file://$LOG4J_CONF \
+    -Dttf.dir=$TTF_DIR \
     -Dwdic-fonts.properties=$FONTS_PROPERTIES \
     -Dwdic-chars.properties=$CHARS_PROPERTIES \
     fuku.xml2eb.converter.wdic.Wdic2Xml "$@"
